package de.java2html.eclipse.dialog;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;

import de.java2html.converter.JavaSourceConverterProvider;

/**
 * @author Markus Gebhard
 */
public class Java2HtmlDialog extends Dialog {

  private Button rbToFile;
  private Combo combo;
  private String outputFormat;
  private boolean convertToFileSelected;

  public Java2HtmlDialog(Shell shell) {
    super(shell);
  }

  /* (non-Javadoc)
   * Method declared in Window.
   */
  protected void configureShell(Shell shell) {
    super.configureShell(shell);
    shell.setText("Java2Html converter");
  }

  protected Control createDialogArea(Composite parent) {
    Composite comp = new Composite(parent, SWT.NONE);
    org.eclipse.swt.layout.GridLayout layout = new GridLayout(1, false);
    layout.marginHeight = 0;
    layout.marginWidth = 0;
    comp.setLayout(layout);
    
    createOutputFormatControl(comp).setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
    createOutputDestinationControl(comp).setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
    
    return comp;
  }

  private Control createOutputDestinationControl(Composite parent) {
    Composite comp = new Composite(parent, SWT.NONE);
    comp.setLayout(new GridLayout(1, false));

    rbToFile = new Button(comp, SWT.RADIO);
    rbToFile.setText("Convert to file");//i18n
    rbToFile.setSelection(false);
    
    Button rbToClipboard = new Button(comp, SWT.RADIO);
    rbToClipboard.setText("Convert to clipboard");//i18n
    rbToClipboard.setSelection(true);

    return comp;
  }

  private Control createOutputFormatControl(Composite parent) {
    Composite comp = new Composite(parent, SWT.NONE);
    comp.setLayout(new GridLayout(2, false));
    
    Label label = new Label(comp, SWT.NONE);
    label.setText("Output format:");//i18n
    
    combo = new Combo(comp, SWT.DROP_DOWN | SWT.READ_ONLY);
    combo.setItems(JavaSourceConverterProvider.getAllConverterPrintNames());
    combo.select(0);
    combo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));    
        
    return comp;
  }

  protected void okPressed() {
    outputFormat = JavaSourceConverterProvider.getAllConverterNames()[combo.getSelectionIndex()];
    convertToFileSelected = rbToFile.getSelection();     
    super.okPressed();
  }

  public boolean isConvertToFileSelected() {
    return convertToFileSelected;
  }

  public String getSelectedOutputFormat() {
    return outputFormat;
  }
}