package de.java2html.eclipse.preferences;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import de.java2html.eclipse.Java2HtmlPlugin;
import de.java2html.options.IConversionOptionsConstants;

/**
 * @author Markus Gebhard
 */
public class Java2HtmlGeneralPreferencePage extends FieldEditorPreferencePage implements IWorkbenchPreferencePage {

  public Java2HtmlGeneralPreferencePage() {
    super(FieldEditorPreferencePage.GRID);
    setPreferenceStore(Java2HtmlPlugin.getDefault().getPreferenceStore());
  }

  protected void createFieldEditors() {
    BooleanFieldEditor showLineNumbers = new BooleanFieldEditor(
        IConversionOptionsConstants.SHOW_LINE_NUMBERS,
        "Show line numbers.",
        BooleanFieldEditor.DEFAULT,
        getFieldEditorParent());
    addField(showLineNumbers);

    BooleanFieldEditor showFileNames = new BooleanFieldEditor(
        IConversionOptionsConstants.SHOW_FILE_NAME,
        "Show file name (if available).",
        BooleanFieldEditor.DEFAULT,
        getFieldEditorParent());
    addField(showFileNames);

    BooleanFieldEditor showTableBorder = new BooleanFieldEditor(
        IConversionOptionsConstants.SHOW_TABLE_BORDER,
        "Show table border.",
        BooleanFieldEditor.DEFAULT,
        getFieldEditorParent());
    addField(showTableBorder);

    IntegerFieldEditor tabSize = new IntegerFieldEditor(
        IConversionOptionsConstants.TAB_SIZE,
        "Tabulator size:",
        getFieldEditorParent());
    tabSize.setEmptyStringAllowed(false);
    tabSize.setValidRange(0, 12);
    tabSize.setErrorMessage("You must enter a value between 0 and 12 for tabulator size.");
    addField(tabSize);
  }

  /**
   * @see IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
   */
  public void init(IWorkbench workbench) {
    //nothing to do
  }
}